@@ -1,11 +1,5 @@
 package GeoIP2::Types;
-{
-  $GeoIP2::Types::VERSION = '0.040001';
-}
-BEGIN {
-  $GeoIP2::Types::AUTHORITY = 'cpan:TJMATHER';
-}
-
+$GeoIP2::Types::VERSION = '0.040002';
 use strict;
 use warnings;
 
@@ -21,6 +15,7 @@ use Exporter qw( import );
 our @EXPORT_OK = qw(
     ArrayRef
     Bool
+    BoolCoercion
     HTTPStatus
     HashRef
     IPAddress
@@ -60,6 +55,17 @@ sub Bool () {
     );
 }
 
+sub BoolCoercion () {
+    return quote_sub(
+        q{ defined $_[0] && Scalar::Util::blessed($_[0])
+               && ( $_[0]->isa('JSON::Boolean')
+                    || $_[0]->isa('JSON::PP::Boolean')
+                    || $_[0]->isa('JSON::XS::Boolean')
+                  )
+                ? $_[0] + 0 : $_[0] }
+    );
+}
+
 sub HTTPStatus () {
     return quote_sub(
         q{ GeoIP2::Types::_tc_fail( $_[0], 'HTTPStatus' )
